﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Text;

public partial class video_modules_vr_all : System.Web.UI.UserControl
{

    private long _videoid = 0;
    private int _pagenumber = 1;
    private int _videoresponses = 0;
    private int _totalrecords = 0;
    private int _pagesize = 40;

    //globalization text
    string showing = Resources.vsk.showing;
    string records = Resources.vsk.records.ToLower();

    public long VideoID
    {
        get
        {
            return _videoid;
        }
        set
        {
            _videoid = value;
        }
    }

    public int VideoResponses
    {
        get
        {
            return _videoresponses;
        }
        set
        {
            _videoresponses = value;
        }
    }

    public int PageNumber
    {
        get
        {
            return _pagenumber;
        }
        set
        {
            _pagenumber = value;
        }
    }

    public int TotalRecords
    {
        get
        {
            return _totalrecords;
        }
        set
        {
            _totalrecords = value;
        }
    }

    public int PageSize
    {
        get
        {
            return _pagesize;
        }
        set
        {
            _pagesize = value;
        }
    }
    
    protected void Page_PreRender(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {

            // Pagination
            if (Request.Params["p"] != null && Request.Params["p"] != "")
            {
                this.PageNumber = Convert.ToInt32(Request.Params["p"]);
            }

            if (!Page.User.Identity.IsAuthenticated)
            {
                // user not autorized
                widget_post_vr.InnerHtml = Resources.vsk.signinpostvideoresponse; // "Sign in to post a Video Response";
                widget_post_vr.HRef = Config.GetUrl() + "Login.aspx?ReturnUrl=" + Config.Return_Current_Page();
            }
            else
            {
                // user autorized
                widget_post_vr.InnerHtml = Resources.vsk.postvideoresponse; // "Post a Video Response";
                widget_post_vr.HRef = Config.GetUrl() + "myaccount/Upload.aspx?vr=" + this.VideoID + "";
            }

            // if comments more than 1
            if (this.VideoResponses > 0)
            {
                t_heading.InnerHtml = Resources.vsk.videoresponses + " (" + this.VideoResponses + " " + Resources.vsk.total + ")";
                // comment exist so load comments
                BindList();
            }
            else
            {
                t_heading.InnerHtml = Resources.vsk.novideoresponse_heading; // "No Video Response";
                // no comments post on this video
                pg.Visible = false;
                lst.Visible = false;
            }
        }
    }

    //// load comments
    private void BindList()
    {
        int media_type = 0; // 0: video, 1: audio
        StringBuilder str = new StringBuilder();
        StringBuilder rotator_str = new StringBuilder();
        List<Video_Struct> _list = VideoBLL.Load_VideoResponses(this.VideoID, this.PageNumber, this.PageSize, media_type);
        if (_list.Count > 0)
        {   if (Config.Return_PaginationType() == 1)
            {
                //MySQL Version Pagination
                this.TotalRecords = Convert.ToInt32(this.VideoResponses); // total no of video responses available.
            }
            else
            {
                // SQL Server Pagination
                this.TotalRecords = _list.Count;
            }
            // Maximum Pagination Restriction for Main Listing
            int maximum_allowed_records = Config.Get_Maximum_Pagination_Links() * this.PageSize;
            if (this.TotalRecords > maximum_allowed_records)
                this.TotalRecords = maximum_allowed_records;

            // List Statistic Display
            list_stat1.TotalRecords = this.TotalRecords;
            list_stat1.PageSize = this.PageSize;
            list_stat1.PageNumber = this.PageNumber;

            // Pagination Setup
            Setup_Pagination();
           
            // generate video gallery
            int i = 0;
            int counter = 0;
            int total_columns = 4;
            VideoItem video = new VideoItem();
            for (i = 0; i <= _list.Count - 1; i++)
            {
                // generate thumb rotator script for single video item  
                rotator_str.Append(UGeneral.Generate_Thumb_Rotator_Script(_list[i].ThumbFileName));
                counter = counter + 1;
                if (counter >= total_columns)
                {
                    counter = 0;
                    video.BreakLine = true;
                }
                video.ShowDate = false;
                video.ShowTitle = true;
                video.ShowAuthor = true;
                video.ShowViews = false;
                video.ShowDownloads = false;
                video.BoxWidth = 100;
                video.Width = 94;
                video.Height = 60;
                video.BoxSpace = 6;
                video.isAdmin = false;
                video.isHoverEffect = false;
                video.TitleLength = 0;
                video.ContentLayout = 0; // 0: contents on bottom, 1: contents on left;
                video.LeftWidth = 45; // % // works with contentlayout=1;
                video.RightWidth = 54; // % // works with contentlayout=1;
                str.Append(video.Process(_list[i]));
                video.BreakLine = false;
            }
            str.Append("<div class=\"clear\"></div>"); // clear floating items
            str.Append("<script type=\"text/javascript\">" + rotator_str.ToString() + "</script>"); // thumb rotator script
        }
        else
        {
            pg.Visible = false;
            str.Append("<div class=\"bx_norecord\">");
            str.Append("<h4>" + Resources.vsk.novideoresponse + "</h4>");
            str.Append("</div>");
        }
        lst.InnerHtml = str.ToString();
    }

    // pagination setup
    private void Setup_Pagination()
    {
        pg.Visible = true;
        pagination1.TotalRecords = this.TotalRecords;
        pagination1.PageSize = this.PageSize;
        pagination1.PageNumber = this.PageNumber;
        pagination1.Default_Url = "video/responses/" + this.VideoID + ".aspx";
        pagination1.Pagination_Url = "video/responses/" + this.VideoID + "/[p].aspx"; // [p] dynamically populate with pagenumber e.g /[p]/ ... /pagenumber/ ... /345/;
        pagination1.BindPagination();
    }
}